Learn R Programming

matrixLaplacian (version 1.0)

matrixLaplacian: Normalized Laplacian Matrix and Laplacian Map

Description

Constructs the normalized Laplacian matrix of a square matrix, returns the eigenvectors (singular vectors) and visualization of normalized Laplacian map.

Usage

matrixLaplacian(A, plot2D=TRUE, plot3D=TRUE)

Arguments

A
a numeric or complex matrix whose normalized Laplacian matrix is to be computed
plot2D
a logical value indicating whether a 2-D map should be plotted
plot3D
a logical value indicating whether a 3-D map should be plotted

Value

LaplacianMatrix
the symmetric normalized Laplacian matrix
eigenvector
the eigenvectors of normalized Laplacian matrix, which are same as singular vectors

Examples

Run this code
#Create a square matrix
A <- matrix(c(1:16), 4, 4)
#Construct normalized Laplacian matrix and plot map
m <- matrixLaplacian(A, plot2D=TRUE, plot3D=TRUE)
#See the eigenvectors
vector<-m$eigenvector

Run the code above in your browser using DataLab